Images stitching (stitching module) {#tutorial_table_of_content_stitching}
===================================

Sometimes a single image can't capture it all. Here you will learn how to join
more images together to create a large pano. Doesn't matter if you want to
create a photo panorama or you want to stitch scans.

-   @subpage tutorial_stitcher

    *Languages:* C++

    *Compatibility:* \>= OpenCV 3.2

    *Author:* Jiri Horner

    You will use high level stitching api to create a photo panorama. You will
    learn about Stitcher class and its configurations.
